# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.ImplementatieElement.AIMObject import AIMObject
from ...Datatypes.KlHellingshoek import KlHellingshoek
from ...Datatypes.KlKopmuurMateriaal import KlKopmuurMateriaal
from otlmow_model.OtlmowModel.GeometrieTypes.VlakGeometrie import VlakGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Kopmuur(AIMObject, VlakGeometrie):
    """Een kopmuur is een inrichtingselement van de wegbaan, dat gebruikt wordt voor de geleiding van verkeer bij grachten. Een kopmuur is een keermuur die een functie vervult van afwateringssysteem en is in de regel haaks op de hartlijn van de wegcorridor georiënteerd. Afgeschuinde varianten worden als meer vergevingsgezind gezien bij een aanrijding."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Kopmuur'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Riooltoegang', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#WaterdoorvoerendeDuiker', direction='o')  # o = direction: outgoing

        self._hellingshoek = OTLAttribuut(field=KlHellingshoek,
                                          naam='hellingshoek',
                                          label='hellingshoek',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Kopmuur.hellingshoek',
                                          definition='De hoek tussen de as van de gracht en het vlak van de kopmuur in graden.',
                                          owner=self)

        self._materiaal = OTLAttribuut(field=KlKopmuurMateriaal,
                                       naam='materiaal',
                                       label='materiaal',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Kopmuur.materiaal',
                                       definition='Bepaalt het materiaal van de kopmuur.',
                                       owner=self)

    @property
    def hellingshoek(self) -> str:
        """De hoek tussen de as van de gracht en het vlak van de kopmuur in graden."""
        return self._hellingshoek.get_waarde()

    @hellingshoek.setter
    def hellingshoek(self, value):
        self._hellingshoek.set_waarde(value, owner=self)

    @property
    def materiaal(self) -> str:
        """Bepaalt het materiaal van de kopmuur."""
        return self._materiaal.get_waarde()

    @materiaal.setter
    def materiaal(self, value):
        self._materiaal.set_waarde(value, owner=self)



# coding=utf-8
from ...Classes.Abstracten.ConstructiefObject import ConstructiefObject
from otlmow_model.OtlmowModel.GeometrieTypes.LijnGeometrie import LijnGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Balansarm(ConstructiefObject, LijnGeometrie):
    """Onderdeel van een balans. Er kunnen één of meerdere balansarmen aanwezig zijn. Het is typisch een lange, horizontale arm die aan lastzijde via een trekker verbonden is met het beweegbare brugdeel ('het val' of ook 'de klap') en aan machtzijde het gebruik van tegengewicht mogelijk maakt."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Balansarm'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#BekledingComponent', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Inloopbehuizing', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#KabelgeleidingEnLeidingBevestiging', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Kast', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#NietWeggebondenDetectie', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Seinlantaarn', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Ventilatie', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Verkeersbord', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Verlichtingstoestel', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Waarschuwingslantaarn', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#ZenderOntvangerToegang', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Binnenverlichtingstoestel', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#StalenProfiel', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Balans', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#BetonnenConstructieObject', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#StalenConstructieObject', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#LigtOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#ConstructieElement', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#LigtOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Laag', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#ComplexeGeleiding', direction='i')  # i = direction: incoming



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.Put import Put
from ...Classes.Abstracten.PutRelatie import PutRelatie
from otlmow_model.OtlmowModel.BaseClasses.BooleanField import BooleanField
from ...Datatypes.DtcAfmetingBxlxhInMm import DtcAfmetingBxlxhInMm, DtcAfmetingBxlxhInMmWaarden
from ...Datatypes.DtcDocument import DtcDocument, DtcDocumentWaarden
from ...Datatypes.KlPutRooster import KlPutRooster
from ...Datatypes.KlRoosterIndeling import KlRoosterIndeling
from ...Datatypes.KlRoosterOpeningswijze import KlRoosterOpeningswijze
from ...Datatypes.KlStraatkolkBakType import KlStraatkolkBakType
from ...Datatypes.KlStraatkolkType import KlStraatkolkType
from ...Datatypes.KlStraatkolkTypeUitlaat import KlStraatkolkTypeUitlaat
from otlmow_model.OtlmowModel.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Straatkolk(Put, PutRelatie, PuntGeometrie):
    """De hemelwaterinlaatconstructie,meestal geplaatst in de straatgoot of watergreppel,waarlangs het hemelwater van de verhardingen wordt afgevoerd."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Straatkolk'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Buis', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#LinkendElement', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#WaterloopRelatie', direction='i')  # i = direction: incoming

        self._aansluitingsfiche = OTLAttribuut(field=DtcDocument,
                                               naam='aansluitingsfiche',
                                               label='aansluitingsfiche',
                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Straatkolk.aansluitingsfiche',
                                               definition='De aansluitingsfiche van de straatkolk.',
                                               owner=self)

        self._bakAfmetingen = OTLAttribuut(field=DtcAfmetingBxlxhInMm,
                                           naam='bakAfmetingen',
                                           label='bak afmetingen',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Straatkolk.bakAfmetingen',
                                           definition='De afmetingen van de bak van de straatkolk in mm.',
                                           owner=self)

        self._bakType = OTLAttribuut(field=KlStraatkolkBakType,
                                     naam='bakType',
                                     label='baktype',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Straatkolk.bakType',
                                     definition='Het type van bak van de straatkolk.',
                                     owner=self)

        self._heeftAfdekplaatReukafsluiter = OTLAttribuut(field=BooleanField,
                                                          naam='heeftAfdekplaatReukafsluiter',
                                                          label='heeft afdekplaat reukafsluiter',
                                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Straatkolk.heeftAfdekplaatReukafsluiter',
                                                          definition='Dit attribuut geeft aan of de straatkolk een afdekplaat als reukafsluiter heeft.',
                                                          owner=self)

        self._isInfiltrerend = OTLAttribuut(field=BooleanField,
                                            naam='isInfiltrerend',
                                            label='is infiltrerend',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Straatkolk.isInfiltrerend',
                                            definition='Wanneer de wanden van de straatkolk poreus zijn (en de straatkolk dus infiltrerend is), kan een deel van het water het water dat in de straatkolk komt rechtstreeks in de grond infiltreren.',
                                            owner=self)

        self._rooster = OTLAttribuut(field=KlPutRooster,
                                     naam='rooster',
                                     label='rooster',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Straatkolk.rooster',
                                     usagenote='Attribuut uit gebruik sinds versie 2.1.0 ',
                                     deprecated_version='2.1.0',
                                     definition='Bepaalt het gebruikte type van rooster.',
                                     owner=self)

        self._roosterIndeling = OTLAttribuut(field=KlRoosterIndeling,
                                             naam='roosterIndeling',
                                             label='rooster indeling',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Straatkolk.roosterIndeling',
                                             definition='Dit attribuut geeft aan hoe het rooster ingedeeld is: met zijdelingse opvang of dat er sprake is van een 1-delig of 2-delig rooster.',
                                             owner=self)

        self._roosterOpeningswijze = OTLAttribuut(field=KlRoosterOpeningswijze,
                                                  naam='roosterOpeningswijze',
                                                  label='rooster openingswijze',
                                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Straatkolk.roosterOpeningswijze',
                                                  definition='Dit attribuut geeft de manier aan hoe het rooster geopend kan worden.',
                                                  owner=self)

        self._type = OTLAttribuut(field=KlStraatkolkType,
                                  naam='type',
                                  label='type',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Straatkolk.type',
                                  definition='Het type van de straatkolk.',
                                  owner=self)

        self._typeUitlaat = OTLAttribuut(field=KlStraatkolkTypeUitlaat,
                                         naam='typeUitlaat',
                                         label='type uitlaat',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Straatkolk.typeUitlaat',
                                         definition='Het type van uitlaat van de straatkolk.',
                                         owner=self)

    @property
    def aansluitingsfiche(self) -> DtcDocumentWaarden:
        """De aansluitingsfiche van de straatkolk."""
        return self._aansluitingsfiche.get_waarde()

    @aansluitingsfiche.setter
    def aansluitingsfiche(self, value):
        self._aansluitingsfiche.set_waarde(value, owner=self)

    @property
    def bakAfmetingen(self) -> DtcAfmetingBxlxhInMmWaarden:
        """De afmetingen van de bak van de straatkolk in mm."""
        return self._bakAfmetingen.get_waarde()

    @bakAfmetingen.setter
    def bakAfmetingen(self, value):
        self._bakAfmetingen.set_waarde(value, owner=self)

    @property
    def bakType(self) -> str:
        """Het type van bak van de straatkolk."""
        return self._bakType.get_waarde()

    @bakType.setter
    def bakType(self, value):
        self._bakType.set_waarde(value, owner=self)

    @property
    def heeftAfdekplaatReukafsluiter(self) -> bool:
        """Dit attribuut geeft aan of de straatkolk een afdekplaat als reukafsluiter heeft."""
        return self._heeftAfdekplaatReukafsluiter.get_waarde()

    @heeftAfdekplaatReukafsluiter.setter
    def heeftAfdekplaatReukafsluiter(self, value):
        self._heeftAfdekplaatReukafsluiter.set_waarde(value, owner=self)

    @property
    def isInfiltrerend(self) -> bool:
        """Wanneer de wanden van de straatkolk poreus zijn (en de straatkolk dus infiltrerend is), kan een deel van het water het water dat in de straatkolk komt rechtstreeks in de grond infiltreren."""
        return self._isInfiltrerend.get_waarde()

    @isInfiltrerend.setter
    def isInfiltrerend(self, value):
        self._isInfiltrerend.set_waarde(value, owner=self)

    @property
    def rooster(self) -> str:
        """Bepaalt het gebruikte type van rooster."""
        return self._rooster.get_waarde()

    @rooster.setter
    def rooster(self, value):
        self._rooster.set_waarde(value, owner=self)

    @property
    def roosterIndeling(self) -> str:
        """Dit attribuut geeft aan hoe het rooster ingedeeld is: met zijdelingse opvang of dat er sprake is van een 1-delig of 2-delig rooster."""
        return self._roosterIndeling.get_waarde()

    @roosterIndeling.setter
    def roosterIndeling(self, value):
        self._roosterIndeling.set_waarde(value, owner=self)

    @property
    def roosterOpeningswijze(self) -> str:
        """Dit attribuut geeft de manier aan hoe het rooster geopend kan worden."""
        return self._roosterOpeningswijze.get_waarde()

    @roosterOpeningswijze.setter
    def roosterOpeningswijze(self, value):
        self._roosterOpeningswijze.set_waarde(value, owner=self)

    @property
    def type(self) -> str:
        """Het type van de straatkolk."""
        return self._type.get_waarde()

    @type.setter
    def type(self, value):
        self._type.set_waarde(value, owner=self)

    @property
    def typeUitlaat(self) -> str:
        """Het type van uitlaat van de straatkolk."""
        return self._typeUitlaat.get_waarde()

    @typeUitlaat.setter
    def typeUitlaat(self, value):
        self._typeUitlaat.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.ElektrischComponentennummerObject import ElektrischComponentennummerObject
from ...Classes.Abstracten.SerienummerObject import SerienummerObject
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from ...Datatypes.KlBypassSchakelaarLocatie import KlBypassSchakelaarLocatie
from ...Datatypes.KlBypassSchakelaarMerk import KlBypassSchakelaarMerk
from ...Datatypes.KlBypassSchakelaarModelnaam import KlBypassSchakelaarModelnaam
from ...Datatypes.KlSchakelaarUitvoering import KlSchakelaarUitvoering
from otlmow_model.OtlmowModel.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class BypassSchakelaar(ElektrischComponentennummerObject, SerienummerObject, AIMNaamObject, PuntGeometrie):
    """Een schakelaar die toelaat om de stroomtoevoer naar afnemende technieken via het geschakeld toestel zoals een UPS, te omzeilen en te isoleren om veilig te kunnen werken aan dat toestel terwijl de stroomtoevoer voor afnemende technieken verzekerd blijft."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#BypassSchakelaar'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#UPS', direction='u')  # u = unidirectional

        self._locatie = OTLAttribuut(field=KlBypassSchakelaarLocatie,
                                     naam='locatie',
                                     label='locatie',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#BypassSchakelaar.locatie',
                                     definition='De locatie van de bypasschakelaar geeft aan of deze zich op de UPS of op het laagspanningsbord bevindt.',
                                     owner=self)

        self._merk = OTLAttribuut(field=KlBypassSchakelaarMerk,
                                  naam='merk',
                                  label='merk',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#BypassSchakelaar.merk',
                                  definition='De merknaam van de schakelaar volgens de fabrikant.',
                                  owner=self)

        self._modelnaam = OTLAttribuut(field=KlBypassSchakelaarModelnaam,
                                       naam='modelnaam',
                                       label='modelnaam',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#BypassSchakelaar.modelnaam',
                                       definition='De modelnaam van de bypass schakelaar volgens de fabrikant.',
                                       owner=self)

        self._uitvoering = OTLAttribuut(field=KlSchakelaarUitvoering,
                                        naam='uitvoering',
                                        label='uitvoering',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#BypassSchakelaar.uitvoering',
                                        definition='De uitvoering van de schakelaar.',
                                        owner=self)

    @property
    def locatie(self) -> str:
        """De locatie van de bypasschakelaar geeft aan of deze zich op de UPS of op het laagspanningsbord bevindt."""
        return self._locatie.get_waarde()

    @locatie.setter
    def locatie(self, value):
        self._locatie.set_waarde(value, owner=self)

    @property
    def merk(self) -> str:
        """De merknaam van de schakelaar volgens de fabrikant."""
        return self._merk.get_waarde()

    @merk.setter
    def merk(self, value):
        self._merk.set_waarde(value, owner=self)

    @property
    def modelnaam(self) -> str:
        """De modelnaam van de bypass schakelaar volgens de fabrikant."""
        return self._modelnaam.get_waarde()

    @modelnaam.setter
    def modelnaam(self, value):
        self._modelnaam.set_waarde(value, owner=self)

    @property
    def uitvoering(self) -> str:
        """De uitvoering van de schakelaar."""
        return self._uitvoering.get_waarde()

    @uitvoering.setter
    def uitvoering(self, value):
        self._uitvoering.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlMIVComkaartType(KeuzelijstField):
    """Mogelijke opties van Com-kaart types."""
    naam = 'KlMIVComkaartType'
    label = 'MIV comkaart type'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlMIVComkaartType'
    definition = 'Mogelijke opties van Com-kaart types.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlMIVComkaartType'
    options = {
        '19-inch': KeuzelijstWaarde(invulwaarde='19-inch',
                                    label='19 inch',
                                    status='ingebruik',
                                    definitie='19 inch',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlMIVComkaartType/19-inch'),
        'module': KeuzelijstWaarde(invulwaarde='module',
                                   label='module',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlMIVComkaartType/module'),
        'sat-module': KeuzelijstWaarde(invulwaarde='sat-module',
                                       label='SAT module',
                                       status='ingebruik',
                                       definitie='SAT module',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlMIVComkaartType/sat-module'),
        'serieel': KeuzelijstWaarde(invulwaarde='serieel',
                                    label='serieel',
                                    status='ingebruik',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlMIVComkaartType/serieel')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlPutRooster(KeuzelijstField):
    """Types rooster van de put."""
    naam = 'KlPutRooster'
    label = 'Putrooster'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlPutRooster'
    definition = 'Types rooster van de put.'
    status = 'ingebruik'
    deprecated_version = '2.1.0'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlPutRooster'
    options = {
        'gietijzeren-rooster-met-zichtvlak-x-hoogte-min.-480-x-330-x-180-mm': KeuzelijstWaarde(invulwaarde='gietijzeren-rooster-met-zichtvlak-x-hoogte-min.-480-x-330-x-180-mm',
                                                                                               label='gietijzeren rooster met zichtvlak x hoogte min. 480 x 330 x 180 mm',
                                                                                               status='ingebruik',
                                                                                               definitie='gietijzeren rooster met zichtvlak x hoogte: min. 480 x 330 x 180 mm',
                                                                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlPutRooster/gietijzeren-rooster-met-zichtvlak-x-hoogte-min.-480-x-330-x-180-mm'),
        'gietijzeren-rooster-met-zichtvlak-x-hoogte-min.-480-x-330-x-200-mm': KeuzelijstWaarde(invulwaarde='gietijzeren-rooster-met-zichtvlak-x-hoogte-min.-480-x-330-x-200-mm',
                                                                                               label='gietijzeren rooster met zichtvlak x hoogte min. 480 x 330 x 200 mm',
                                                                                               status='ingebruik',
                                                                                               definitie='gietijzeren rooster met zichtvlak x hoogte: min. 480 x 330 x 200 mm',
                                                                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlPutRooster/gietijzeren-rooster-met-zichtvlak-x-hoogte-min.-480-x-330-x-200-mm'),
        'gietijzeren-rooster-met-zichtvlak-x-hoogte-min.-480-x-330-x-230-mm': KeuzelijstWaarde(invulwaarde='gietijzeren-rooster-met-zichtvlak-x-hoogte-min.-480-x-330-x-230-mm',
                                                                                               label='gietijzeren rooster met zichtvlak x hoogte min. 480 x 330 x 230 mm',
                                                                                               status='ingebruik',
                                                                                               definitie='gietijzeren rooster met zichtvlak x hoogte: min. 480 x 330 x 230 mm',
                                                                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlPutRooster/gietijzeren-rooster-met-zichtvlak-x-hoogte-min.-480-x-330-x-230-mm'),
        'gietijzeren-rooster-met-zichtvlak-x-hoogte-min.-535-x-330-x-168-mm': KeuzelijstWaarde(invulwaarde='gietijzeren-rooster-met-zichtvlak-x-hoogte-min.-535-x-330-x-168-mm',
                                                                                               label='gietijzeren rooster met zichtvlak x hoogte min. 535 x 330 x 168 mm',
                                                                                               status='ingebruik',
                                                                                               definitie='gietijzeren rooster met zichtvlak x hoogte: min. 535 x 330 x 168 mm',
                                                                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlPutRooster/gietijzeren-rooster-met-zichtvlak-x-hoogte-min.-535-x-330-x-168-mm'),
        'gietijzeren-rooster-met-zichtvlak-x-hoogte-min.-540-x-280-x-230-mm': KeuzelijstWaarde(invulwaarde='gietijzeren-rooster-met-zichtvlak-x-hoogte-min.-540-x-280-x-230-mm',
                                                                                               label='gietijzeren rooster met zichtvlak x hoogte min. 540 x 280 x 230 mm',
                                                                                               status='ingebruik',
                                                                                               definitie='gietijzeren rooster met zichtvlak x hoogte: min. 540 x 280 x 230 mm',
                                                                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlPutRooster/gietijzeren-rooster-met-zichtvlak-x-hoogte-min.-540-x-280-x-230-mm'),
        'gietijzeren-rooster-met-zichtvlak-x-hoogte-min.-540-x-340-x-180-mm': KeuzelijstWaarde(invulwaarde='gietijzeren-rooster-met-zichtvlak-x-hoogte-min.-540-x-340-x-180-mm',
                                                                                               label='gietijzeren rooster met zichtvlak x hoogte min. 540 x 340 x 180 mm',
                                                                                               status='ingebruik',
                                                                                               definitie='gietijzeren rooster met zichtvlak x hoogte: min. 540 x 340 x 180 mm',
                                                                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlPutRooster/gietijzeren-rooster-met-zichtvlak-x-hoogte-min.-540-x-340-x-180-mm'),
        'gietijzeren-rooster-met-zichtvlak-x-hoogte-min.-540-x-340-x-240-mm': KeuzelijstWaarde(invulwaarde='gietijzeren-rooster-met-zichtvlak-x-hoogte-min.-540-x-340-x-240-mm',
                                                                                               label='gietijzeren rooster met zichtvlak x hoogte min. 540 x 340 x 240 mm',
                                                                                               status='ingebruik',
                                                                                               definitie='gietijzeren rooster met zichtvlak x hoogte: min. 540 x 340 x 240 mm',
                                                                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlPutRooster/gietijzeren-rooster-met-zichtvlak-x-hoogte-min.-540-x-340-x-240-mm'),
        'gietijzeren-rooster-met-zichtvlak-x-hoogte-min.-605-x-290-x-205-mm': KeuzelijstWaarde(invulwaarde='gietijzeren-rooster-met-zichtvlak-x-hoogte-min.-605-x-290-x-205-mm',
                                                                                               label='gietijzeren rooster met zichtvlak x hoogte min. 605 x 290 x 205 mm',
                                                                                               status='ingebruik',
                                                                                               definitie='gietijzeren rooster met zichtvlak x hoogte: min. 605 x 290 x 205 mm',
                                                                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlPutRooster/gietijzeren-rooster-met-zichtvlak-x-hoogte-min.-605-x-290-x-205-mm'),
        'volledig-gietijzeren-straatkolk': KeuzelijstWaarde(invulwaarde='volledig-gietijzeren-straatkolk',
                                                            label='volledig gietijzeren straatkolk',
                                                            status='ingebruik',
                                                            definitie='volledig gietijzeren straatkolk',
                                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlPutRooster/volledig-gietijzeren-straatkolk'),
        'volledig-gietijzeren-straatkolk-zichtvlak-x-hoogte-min.-500-x-500-x-640-mm': KeuzelijstWaarde(invulwaarde='volledig-gietijzeren-straatkolk-zichtvlak-x-hoogte-min.-500-x-500-x-640-mm',
                                                                                                       label='volledig gietijzeren straatkolk zichtvlak x hoogte min. 500 x 500 x 640 mm',
                                                                                                       status='ingebruik',
                                                                                                       definitie='volledig gietijzeren straatkolk zichtvlak x hoogte: min. 500 x 500 x 640 mm',
                                                                                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlPutRooster/volledig-gietijzeren-straatkolk-zichtvlak-x-hoogte-min.-500-x-500-x-640-mm'),
        'volledig-gietijzeren-straatkolk-zichtvlak-x-hoogte-min.-500-x-500-x-650-mm': KeuzelijstWaarde(invulwaarde='volledig-gietijzeren-straatkolk-zichtvlak-x-hoogte-min.-500-x-500-x-650-mm',
                                                                                                       label='volledig gietijzeren straatkolk zichtvlak x hoogte min. 500 x 500 x 650 mm',
                                                                                                       status='ingebruik',
                                                                                                       definitie='volledig gietijzeren straatkolk zichtvlak x hoogte: min. 500 x 500 x 650 mm',
                                                                                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlPutRooster/volledig-gietijzeren-straatkolk-zichtvlak-x-hoogte-min.-500-x-500-x-650-mm'),
        'volledig-gietijzeren-straatkolk-zichtvlak-x-hoogte-min.-665-x-230-x-570-mm': KeuzelijstWaarde(invulwaarde='volledig-gietijzeren-straatkolk-zichtvlak-x-hoogte-min.-665-x-230-x-570-mm',
                                                                                                       label='volledig gietijzeren straatkolk zichtvlak x hoogte min. 665 x 230 x 570 mm',
                                                                                                       status='ingebruik',
                                                                                                       definitie='volledig gietijzeren straatkolk zichtvlak x hoogte: min. 665 x 230 x 570 mm',
                                                                                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlPutRooster/volledig-gietijzeren-straatkolk-zichtvlak-x-hoogte-min.-665-x-230-x-570-mm'),
        'volledig-gietijzeren-straatkolk-zichtvlak-x-hoogte-min.-785-x-300-x-400-mm': KeuzelijstWaarde(invulwaarde='volledig-gietijzeren-straatkolk-zichtvlak-x-hoogte-min.-785-x-300-x-400-mm',
                                                                                                       label='volledig gietijzeren straatkolk zichtvlak x hoogte min. 785 x 300 x 400 mm',
                                                                                                       status='ingebruik',
                                                                                                       definitie='volledig gietijzeren straatkolk zichtvlak x hoogte: min. 785 x 300 x 400 mm',
                                                                                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlPutRooster/volledig-gietijzeren-straatkolk-zichtvlak-x-hoogte-min.-785-x-300-x-400-mm'),
        'volledig-gietijzeren-straatkolk-zichtvlak-x-hoogte-min.-785-x-300-x-655-mm': KeuzelijstWaarde(invulwaarde='volledig-gietijzeren-straatkolk-zichtvlak-x-hoogte-min.-785-x-300-x-655-mm',
                                                                                                       label='volledig gietijzeren straatkolk zichtvlak x hoogte min. 785 x 300 x 655 mm',
                                                                                                       status='ingebruik',
                                                                                                       definitie='volledig gietijzeren straatkolk zichtvlak x hoogte: min. 785 x 300 x 655 mm',
                                                                                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlPutRooster/volledig-gietijzeren-straatkolk-zichtvlak-x-hoogte-min.-785-x-300-x-655-mm')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.BalkGK import BalkGK
from otlmow_model.OtlmowModel.BaseClasses.BooleanField import BooleanField


# Generated with OTLClassCreator. To modify: extend, do not edit
class Verdeelbalk(BalkGK):
    """Een constructief element dat de belasting op een grondkerende constructie, zoals een damwand of beschoeiing, verdeelt naar meerdere ankerstaven of andere steunpunten. Het zorgt voor een gelijkmatige(re) spreiding van de belastingen op de constructie en vormt zo mee een essentieel onderdeel van de structuur."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Verdeelbalk'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#BekledingComponent', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Inloopbehuizing', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#KabelgeleidingEnLeidingBevestiging', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Kast', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#NietWeggebondenDetectie', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Seinlantaarn', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Ventilatie', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Verkeersbord', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Verlichtingstoestel', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Waarschuwingslantaarn', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#ZenderOntvangerToegang', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Binnenverlichtingstoestel', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#StalenProfiel', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#BetonnenConstructieObject', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#StalenConstructieObject', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#LigtOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#ConstructieElement', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#LigtOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Laag', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#ComplexeGeleiding', direction='i')  # i = direction: incoming

        self._heeftKraanrail = OTLAttribuut(field=BooleanField,
                                            naam='heeftKraanrail',
                                            label='heeft kraanrail',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Verdeelbalk.heeftKraanrail',
                                            definition='Geeft aan of er kraainrail aanwezig is.',
                                            owner=self)

    @property
    def heeftKraanrail(self) -> bool:
        """Geeft aan of er kraainrail aanwezig is."""
        return self._heeftKraanrail.get_waarde()

    @heeftKraanrail.setter
    def heeftKraanrail(self, value):
        self._heeftKraanrail.set_waarde(value, owner=self)



# coding=utf-8
from ...Classes.Abstracten.ConstructiefObject import ConstructiefObject
from otlmow_model.OtlmowModel.GeometrieTypes.VlakGeometrie import VlakGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Boog(ConstructiefObject, VlakGeometrie):
    """Een gebogen overspanning (boven een opening), tussen twee steunpunten en ter ondersteuning van een brug, waarbij de druk (ook) zijdelings wordt afgevoerd."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Boog'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#BekledingComponent', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Inloopbehuizing', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#KabelgeleidingEnLeidingBevestiging', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Kast', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#NietWeggebondenDetectie', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Seinlantaarn', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Ventilatie', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Verkeersbord', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Verlichtingstoestel', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Waarschuwingslantaarn', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#ZenderOntvangerToegang', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Binnenverlichtingstoestel', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#StalenProfiel', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Brugdeel', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#BetonnenConstructieObject', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#StalenConstructieObject', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#LigtOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#ConstructieElement', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#LigtOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Laag', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#ComplexeGeleiding', direction='i')  # i = direction: incoming



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from abc import abstractmethod, ABC
from ...Datatypes.KlStaalsoortMetEquivalenten import KlStaalsoortMetEquivalenten


# Generated with OTLClassCreator. To modify: extend, do not edit
class StaalsoortObject(ABC):
    """Abstracte met staalsoorten"""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#StaalsoortObject'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    @abstractmethod
    def __init__(self):
        super().__init__()

        self._materiaal = OTLAttribuut(field=KlStaalsoortMetEquivalenten,
                                       naam='materiaal',
                                       label='staalsoorten',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#StaalsoortObject.materiaal',
                                       definition='Lijst van staalsoorten (constructiestaal, gietstaal, veredelstaal, smeedstaan en roestvaststaal)',
                                       owner=self)

    @property
    def materiaal(self) -> str:
        """Lijst van staalsoorten (constructiestaal, gietstaal, veredelstaal, smeedstaan en roestvaststaal)"""
        return self._materiaal.get_waarde()

    @materiaal.setter
    def materiaal(self, value):
        self._materiaal.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from ...Datatypes.KlVastTegengewichtMateriaal import KlVastTegengewichtMateriaal
from otlmow_model.OtlmowModel.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class VastTegengewicht(AIMNaamObject, PuntGeometrie):
    """Het vast tegengewicht betreft de hoeveelheid massa die onlosmakelijk met de machtarm is verbonden om (mee) het bewegende brugdeel te balanceren. De hoeveelheid massa benadert de vooropgestelde mate van onevenwicht. De massa kan bestaan uit beton, steen, staal, gietijzer of lood dat permanent ingewerkt is in de constructie."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VastTegengewicht'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Staalkabel', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Balans', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Brugdeel', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Brugligger', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Hefportiek', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Heftoren', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Kabelbewegingsmechanisme', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Tegengewichtkist', direction='o')  # o = direction: outgoing

        self._materiaal = OTLAttribuut(field=KlVastTegengewichtMateriaal,
                                       naam='materiaal',
                                       label='materiaal',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VastTegengewicht.materiaal',
                                       definition='Het materiaal van het vaste tegengewicht.',
                                       owner=self)

    @property
    def materiaal(self) -> str:
        """Het materiaal van het vaste tegengewicht."""
        return self._materiaal.get_waarde()

    @materiaal.setter
    def materiaal(self, value):
        self._materiaal.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.BalkGK import BalkGK
from otlmow_model.OtlmowModel.BaseClasses.BooleanField import BooleanField


# Generated with OTLClassCreator. To modify: extend, do not edit
class Koppelbalk(BalkGK):
    """Een balk die delen van een constructie met elkaar verbindt."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Koppelbalk'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#BekledingComponent', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Inloopbehuizing', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#KabelgeleidingEnLeidingBevestiging', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Kast', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#NietWeggebondenDetectie', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Seinlantaarn', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Ventilatie', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Verkeersbord', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Verlichtingstoestel', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Waarschuwingslantaarn', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#ZenderOntvangerToegang', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Binnenverlichtingstoestel', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#StalenProfiel', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#BetonnenConstructieObject', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#StalenConstructieObject', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#LigtOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#ConstructieElement', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#LigtOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Laag', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#ComplexeGeleiding', direction='i')  # i = direction: incoming

        self._heeftKraanrail = OTLAttribuut(field=BooleanField,
                                            naam='heeftKraanrail',
                                            label='heeft kraainrail',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Koppelbalk.heeftKraanrail',
                                            definition='Geeft aan of er kraainrail aanwezig is.',
                                            owner=self)

    @property
    def heeftKraanrail(self) -> bool:
        """Geeft aan of er kraainrail aanwezig is."""
        return self._heeftKraanrail.get_waarde()

    @heeftKraanrail.setter
    def heeftKraanrail(self, value):
        self._heeftKraanrail.set_waarde(value, owner=self)



# coding=utf-8
from abc import abstractmethod
from ...Classes.ImplementatieElement.RelatieObject import RelatieObject


# Generated with OTLClassCreator. To modify: extend, do not edit
class NietDirectioneleRelatie(RelatieObject):
    """Een abstracte die relaties groepeert waarbij de richting semantisch niet gedefinieerd is."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/implementatieelement#NietDirectioneleRelatie'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    @abstractmethod
    def __init__(self):
        super().__init__()



# coding=utf-8
from typing import List
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from abc import abstractmethod
from ...Classes.Abstracten.BijlageVoertuigkering import BijlageVoertuigkering
from ...Classes.Abstracten.LijnvormigElement import LijnvormigElement
from otlmow_model.OtlmowModel.BaseClasses.BooleanField import BooleanField
from ...Datatypes.DtcDocument import DtcDocument, DtcDocumentWaarden
from ...Datatypes.DtcProductidentificatiecode import DtcProductidentificatiecode, DtcProductidentificatiecodeWaarden
from ...Datatypes.KlLEACMateriaal import KlLEACMateriaal
from otlmow_model.OtlmowModel.BaseClasses.StringField import StringField


# Generated with OTLClassCreator. To modify: extend, do not edit
class AfschermendeConstructie(BijlageVoertuigkering, LijnvormigElement):
    """Abstracte die een lijn- of puntvormige constructie,geïnstalleerd langs de weg om een kerend vermogen te bieden aan een dwalend voertuig,samenvat."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#AfschermendeConstructie'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    @abstractmethod
    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Fundering', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#KabelgeleidingEnLeidingBevestiging', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#GeluidswerendeConstructie', direction='u', deprecated='2.0.0')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Referentiepunt', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#WegbebakeningAfschermendeConstructies', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IsInspectieVan', target='https://wegenenverkeer.data.vlaanderen.be/ns/proefenmeting#ProefGrondkarakteristieken', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#LigtOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#GeluidswerendeConstructie', direction='i', deprecated='2.0.0')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#GeluidswerendeConstructie', direction='o', deprecated='2.0.0')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VoertuigkerendGeluidsschermelement', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#GeluidswerendeConstructie', direction='i', deprecated='2.0.0')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VoertuigkerendGeluidsschermelement', direction='i')  # i = direction: incoming

        self._certificaathouder = OTLAttribuut(field=StringField,
                                               naam='certificaathouder',
                                               label='certificaathouder',
                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#AfschermendeConstructie.certificaathouder',
                                               definition='De houder van het uitvoeringscertificaat.',
                                               owner=self)

        self._isPermanent = OTLAttribuut(field=BooleanField,
                                         naam='isPermanent',
                                         label='is permanent',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#AfschermendeConstructie.isPermanent',
                                         definition='Vermelding of de afschermende constructie al dan niet van permanente aard is.',
                                         owner=self)

        self._materiaal = OTLAttribuut(field=KlLEACMateriaal,
                                       naam='materiaal',
                                       label='materiaal',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#AfschermendeConstructie.materiaal',
                                       definition='Het gebruikte materiaal voor de afschermende constructie.',
                                       owner=self)

        self._metTandGroef = OTLAttribuut(field=BooleanField,
                                          naam='metTandGroef',
                                          label='met tand-groef',
                                          objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#AfschermendeConstructie.metTandGroef',
                                          definition='Geeft aan of de afschermende constructie bevestigd is aan de onderliggende laag door middel van een tand-groef aansluiting.',
                                          owner=self)

        self._productidentificatiecode = OTLAttribuut(field=DtcProductidentificatiecode,
                                                      naam='productidentificatiecode',
                                                      label='productidentificatiecode',
                                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#AfschermendeConstructie.productidentificatiecode',
                                                      definition='De productidentificatiecode voor het bepalen van de code van het gebruikte product (bv. COPRO/BENOR).',
                                                      owner=self)

        self._productnaam = OTLAttribuut(field=StringField,
                                         naam='productnaam',
                                         label='productnaam',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#AfschermendeConstructie.productnaam',
                                         definition='Dit is de commerciële naam van de afschermende constructie.',
                                         owner=self)

        self._testrapport = OTLAttribuut(field=DtcDocument,
                                         naam='testrapport',
                                         label='testrapport',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#AfschermendeConstructie.testrapport',
                                         usagenote='Attribuut uit gebruik sinds versie 2.0.0 ',
                                         deprecated_version='2.0.0',
                                         kardinaliteit_max='*',
                                         definition='De testresultaten van een afschermende constructie.',
                                         owner=self)

        self._uitvoeringscertificatie = OTLAttribuut(field=DtcDocument,
                                                     naam='uitvoeringscertificatie',
                                                     label='uitvoeringscertificatie',
                                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#AfschermendeConstructie.uitvoeringscertificatie',
                                                     usagenote='Bestanden van het type xlsx of pdf.',
                                                     definition='Documentatie van het certificaat.',
                                                     owner=self)

        self._video = OTLAttribuut(field=DtcDocument,
                                   naam='video',
                                   label='video',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#AfschermendeConstructie.video',
                                   usagenote='Attribuut uit gebruik sinds versie 2.0.0 ',
                                   deprecated_version='2.0.0',
                                   kardinaliteit_max='*',
                                   definition='Video van de testen op afschermende constructies.',
                                   owner=self)

    @property
    def certificaathouder(self) -> str:
        """De houder van het uitvoeringscertificaat."""
        return self._certificaathouder.get_waarde()

    @certificaathouder.setter
    def certificaathouder(self, value):
        self._certificaathouder.set_waarde(value, owner=self)

    @property
    def isPermanent(self) -> bool:
        """Vermelding of de afschermende constructie al dan niet van permanente aard is."""
        return self._isPermanent.get_waarde()

    @isPermanent.setter
    def isPermanent(self, value):
        self._isPermanent.set_waarde(value, owner=self)

    @property
    def materiaal(self) -> str:
        """Het gebruikte materiaal voor de afschermende constructie."""
        return self._materiaal.get_waarde()

    @materiaal.setter
    def materiaal(self, value):
        self._materiaal.set_waarde(value, owner=self)

    @property
    def metTandGroef(self) -> bool:
        """Geeft aan of de afschermende constructie bevestigd is aan de onderliggende laag door middel van een tand-groef aansluiting."""
        return self._metTandGroef.get_waarde()

    @metTandGroef.setter
    def metTandGroef(self, value):
        self._metTandGroef.set_waarde(value, owner=self)

    @property
    def productidentificatiecode(self) -> DtcProductidentificatiecodeWaarden:
        """De productidentificatiecode voor het bepalen van de code van het gebruikte product (bv. COPRO/BENOR)."""
        return self._productidentificatiecode.get_waarde()

    @productidentificatiecode.setter
    def productidentificatiecode(self, value):
        self._productidentificatiecode.set_waarde(value, owner=self)

    @property
    def productnaam(self) -> str:
        """Dit is de commerciële naam van de afschermende constructie."""
        return self._productnaam.get_waarde()

    @productnaam.setter
    def productnaam(self, value):
        self._productnaam.set_waarde(value, owner=self)

    @property
    def testrapport(self) -> List[DtcDocumentWaarden]:
        """De testresultaten van een afschermende constructie."""
        return self._testrapport.get_waarde()

    @testrapport.setter
    def testrapport(self, value):
        self._testrapport.set_waarde(value, owner=self)

    @property
    def uitvoeringscertificatie(self) -> DtcDocumentWaarden:
        """Documentatie van het certificaat."""
        return self._uitvoeringscertificatie.get_waarde()

    @uitvoeringscertificatie.setter
    def uitvoeringscertificatie(self, value):
        self._uitvoeringscertificatie.set_waarde(value, owner=self)

    @property
    def video(self) -> List[DtcDocumentWaarden]:
        """Video van de testen op afschermende constructies."""
        return self._video.get_waarde()

    @video.setter
    def video(self, value):
        self._video.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.AanhorighedenBrug import AanhorighedenBrug
from ...Classes.Abstracten.AanhorigheidKoker import AanhorigheidKoker
from ...Classes.Abstracten.AanhorigheidSluisStuw import AanhorigheidSluisStuw
from ...Classes.Abstracten.DetaiplanObject import DetaiplanObject
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from otlmow_model.OtlmowModel.BaseClasses.BooleanField import BooleanField
from ...Datatypes.DtcDocument import DtcDocument, DtcDocumentWaarden
from ...Datatypes.KlAfwerkingstypeLeuning import KlAfwerkingstypeLeuning
from ...Datatypes.KlAlgMateriaal import KlAlgMateriaal
from ...Datatypes.KlVormLeuning import KlVormLeuning
from ...Datatypes.KwantWrdInMeter import KwantWrdInMeter, KwantWrdInMeterWaarden
from otlmow_model.OtlmowModel.GeometrieTypes.LijnGeometrie import LijnGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Leuning(AanhorighedenBrug, AanhorigheidKoker, AanhorigheidSluisStuw, DetaiplanObject, AIMNaamObject, LijnGeometrie):
    """Een leuning is een constructie waaraan men met een hand steun of stabiliteit kan vinden om niet in de diepte te vallen. Ze kan bestaan uit een stevige balk, strip of touw maar ook uit een boven- en onderregel en stijlen."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Leuning'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Kokerruimte', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Kesp', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Loopvloer', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Seinbrug', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Trap', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#VerlichtingstoestelLED', direction='u')  # u = unidirectional

        self._afwerkingstype = OTLAttribuut(field=KlAfwerkingstypeLeuning,
                                            naam='afwerkingstype',
                                            label='afwerkingstype',
                                            objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Leuning.afwerkingstype',
                                            definition='Het type afwerking van de leuning.',
                                            owner=self)

        self._hoogte = OTLAttribuut(field=KwantWrdInMeter,
                                    naam='hoogte',
                                    label='hoogte',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Leuning.hoogte',
                                    definition='De hoogte van de leuning.',
                                    owner=self)

        self._lengte = OTLAttribuut(field=KwantWrdInMeter,
                                    naam='lengte',
                                    label='lengte',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Leuning.lengte',
                                    definition='De lengte van de leuning.',
                                    owner=self)

        self._materiaal = OTLAttribuut(field=KlAlgMateriaal,
                                       naam='materiaal',
                                       label='materiaal',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Leuning.materiaal',
                                       definition='Het materiaal waaruit de leuning is vervaardigd.',
                                       owner=self)

        self._professioneelGebruik = OTLAttribuut(field=BooleanField,
                                                  naam='professioneelGebruik',
                                                  label='professioneel gebruik',
                                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Leuning.professioneelGebruik',
                                                  definition='Geeft aan of het gebruik enkel voor professionelen is of ook publiekeliGeeft aan of het gebruik enkel voor professionelen is of ook publiekelijk gebruikt wordt.',
                                                  owner=self)

        self._technischeFiche = OTLAttribuut(field=DtcDocument,
                                             naam='technischeFiche',
                                             label='technische fiche',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Leuning.technischeFiche',
                                             definition='De technische fiche van de leuning.',
                                             owner=self)

        self._vorm = OTLAttribuut(field=KlVormLeuning,
                                  naam='vorm',
                                  label='vorm',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Leuning.vorm',
                                  definition='De vorm van de leuning',
                                  owner=self)

    @property
    def afwerkingstype(self) -> str:
        """Het type afwerking van de leuning."""
        return self._afwerkingstype.get_waarde()

    @afwerkingstype.setter
    def afwerkingstype(self, value):
        self._afwerkingstype.set_waarde(value, owner=self)

    @property
    def hoogte(self) -> KwantWrdInMeterWaarden:
        """De hoogte van de leuning."""
        return self._hoogte.get_waarde()

    @hoogte.setter
    def hoogte(self, value):
        self._hoogte.set_waarde(value, owner=self)

    @property
    def lengte(self) -> KwantWrdInMeterWaarden:
        """De lengte van de leuning."""
        return self._lengte.get_waarde()

    @lengte.setter
    def lengte(self, value):
        self._lengte.set_waarde(value, owner=self)

    @property
    def materiaal(self) -> str:
        """Het materiaal waaruit de leuning is vervaardigd."""
        return self._materiaal.get_waarde()

    @materiaal.setter
    def materiaal(self, value):
        self._materiaal.set_waarde(value, owner=self)

    @property
    def professioneelGebruik(self) -> bool:
        """Geeft aan of het gebruik enkel voor professionelen is of ook publiekeliGeeft aan of het gebruik enkel voor professionelen is of ook publiekelijk gebruikt wordt."""
        return self._professioneelGebruik.get_waarde()

    @professioneelGebruik.setter
    def professioneelGebruik(self, value):
        self._professioneelGebruik.set_waarde(value, owner=self)

    @property
    def technischeFiche(self) -> DtcDocumentWaarden:
        """De technische fiche van de leuning."""
        return self._technischeFiche.get_waarde()

    @technischeFiche.setter
    def technischeFiche(self, value):
        self._technischeFiche.set_waarde(value, owner=self)

    @property
    def vorm(self) -> str:
        """De vorm van de leuning"""
        return self._vorm.get_waarde()

    @vorm.setter
    def vorm(self, value):
        self._vorm.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.LinkendElement import LinkendElement
from ...Datatypes.KwantWrdInMeterTAW import KwantWrdInMeterTAW, KwantWrdInMeterTAWWaarden
from otlmow_model.OtlmowModel.GeometrieTypes.VlakGeometrie import VlakGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Wervel(LinkendElement, VlakGeometrie):
    """Een wervel is een debietsbeperkend element dat zich tussen 2 kamers of tussen een kamer en een leiding bevindt."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Wervel'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Brandvoorziening', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Buis', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#LinkendElement', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#PutRelatie', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#WaterloopRelatie', direction='i')  # i = direction: incoming

        self._peil = OTLAttribuut(field=KwantWrdInMeterTAW,
                                  naam='peil',
                                  label='peil',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Wervel.peil',
                                  definition='Dit is het niveau in meter-TAW van de inlaat van het wervelventiel.',
                                  owner=self)

    @property
    def peil(self) -> KwantWrdInMeterTAWWaarden:
        """Dit is het niveau in meter-TAW van de inlaat van het wervelventiel."""
        return self._peil.get_waarde()

    @peil.setter
    def peil(self, value):
        self._peil.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlWvLedVerlNiveau(KeuzelijstField):
    """Een set van verlichtingstechnische eisen zoals gemiddelde luminantie, verlichtingsterkte, uniformeiten."""
    naam = 'KlWvLedVerlNiveau'
    label = 'WV LED verlichtingsniveau'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlWvLedVerlNiveau'
    definition = 'Een set van verlichtingstechnische eisen zoals gemiddelde luminantie, verlichtingsterkte, uniformeiten.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlWvLedVerlNiveau'
    options = {
        'C1': KeuzelijstWaarde(invulwaarde='C1',
                               label='C1',
                               status='ingebruik',
                               definitie='C1',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedVerlNiveau/C1'),
        'C2': KeuzelijstWaarde(invulwaarde='C2',
                               label='C2',
                               status='ingebruik',
                               definitie='C2',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedVerlNiveau/C2'),
        'C3': KeuzelijstWaarde(invulwaarde='C3',
                               label='C3',
                               status='ingebruik',
                               definitie='C3',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedVerlNiveau/C3'),
        'C4': KeuzelijstWaarde(invulwaarde='C4',
                               label='C4',
                               status='ingebruik',
                               definitie='C4',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedVerlNiveau/C4'),
        'M2': KeuzelijstWaarde(invulwaarde='M2',
                               label='M2',
                               status='ingebruik',
                               definitie='M2',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedVerlNiveau/M2'),
        'M3': KeuzelijstWaarde(invulwaarde='M3',
                               label='M3',
                               status='ingebruik',
                               definitie='M3',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedVerlNiveau/M3'),
        'M4': KeuzelijstWaarde(invulwaarde='M4',
                               label='M4',
                               status='ingebruik',
                               definitie='M4',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedVerlNiveau/M4'),
        'P3': KeuzelijstWaarde(invulwaarde='P3',
                               label='P3',
                               status='ingebruik',
                               definitie='P3',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedVerlNiveau/P3'),
        'P4': KeuzelijstWaarde(invulwaarde='P4',
                               label='P4',
                               status='ingebruik',
                               definitie='P4',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedVerlNiveau/P4'),
        'P5': KeuzelijstWaarde(invulwaarde='P5',
                               label='P5',
                               status='ingebruik',
                               definitie='P5',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedVerlNiveau/P5'),
        'ZL': KeuzelijstWaarde(invulwaarde='ZL',
                               label='ZL',
                               status='ingebruik',
                               definitie='ZL',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedVerlNiveau/ZL'),
        'ZR': KeuzelijstWaarde(invulwaarde='ZR',
                               label='ZR',
                               status='ingebruik',
                               definitie='ZR',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedVerlNiveau/ZR'),
        'c5': KeuzelijstWaarde(invulwaarde='c5',
                               label='C5',
                               status='ingebruik',
                               definitie='C5',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedVerlNiveau/c5'),
        'm3-0': KeuzelijstWaarde(invulwaarde='m3-0',
                                 label='M3+0',
                                 status='ingebruik',
                                 definitie='M3+0',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedVerlNiveau/m3-0'),
        'm3-c4': KeuzelijstWaarde(invulwaarde='m3-c4',
                                  label='M3+C4',
                                  status='ingebruik',
                                  definitie='M3+C4',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedVerlNiveau/m3-c4'),
        'm3-p4': KeuzelijstWaarde(invulwaarde='m3-p4',
                                  label='M3+P4',
                                  status='ingebruik',
                                  definitie='M3+P4',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedVerlNiveau/m3-p4'),
        'm4-c5': KeuzelijstWaarde(invulwaarde='m4-c5',
                                  label='M4+C5',
                                  status='ingebruik',
                                  definitie='M4+C5',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedVerlNiveau/m4-c5'),
        'm4-p4': KeuzelijstWaarde(invulwaarde='m4-p4',
                                  label='M4+P4',
                                  status='ingebruik',
                                  definitie='M4+P4',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedVerlNiveau/m4-p4'),
        'm5': KeuzelijstWaarde(invulwaarde='m5',
                               label='M5',
                               status='ingebruik',
                               definitie='M5',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedVerlNiveau/m5'),
        'zl3': KeuzelijstWaarde(invulwaarde='zl3',
                                label='ZL3',
                                status='ingebruik',
                                definitie='ZL3',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedVerlNiveau/zl3'),
        'zl4': KeuzelijstWaarde(invulwaarde='zl4',
                                label='ZL4',
                                status='ingebruik',
                                definitie='ZL4',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedVerlNiveau/zl4'),
        'zr3': KeuzelijstWaarde(invulwaarde='zr3',
                                label='ZR3',
                                status='ingebruik',
                                definitie='ZR3',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedVerlNiveau/zr3'),
        'zr4': KeuzelijstWaarde(invulwaarde='zr4',
                                label='ZR4',
                                status='ingebruik',
                                definitie='ZR4',
                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlWvLedVerlNiveau/zr4')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.AfschermendeConstructie import AfschermendeConstructie
from ...Datatypes.KlLEACSchokindexMVP import KlLEACSchokindexMVP
from ...Datatypes.KlLEACSnelheidsklasse import KlLEACSnelheidsklasse
from ...Datatypes.KwantWrdInMeter import KwantWrdInMeter, KwantWrdInMeterWaarden
from otlmow_model.OtlmowModel.GeometrieTypes.LijnGeometrie import LijnGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Motorvangplank(AfschermendeConstructie, LijnGeometrie):
    """Een constructie geïnstalleerd aan een geleideconstructie of in de onmiddellijke omgeving ervan,met als doel de ernst van een botsing van een motorrijder met de geleideconstructie te reduceren."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Motorvangplank'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#AansluitendeConstructie', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Fundering', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#KabelgeleidingEnLeidingBevestiging', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Eindstuk', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#NietGetestBeginstuk', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IsInspectieVan', target='https://wegenenverkeer.data.vlaanderen.be/ns/proefenmeting#ProefSchokindexMVP', direction='i', deprecated='2.0.0')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IsInspectieVan', target='https://wegenenverkeer.data.vlaanderen.be/ns/proefenmeting#ProefWerkingsbreedteMVP', direction='i', deprecated='2.0.0')  # i = direction: incoming

        self._lengte = OTLAttribuut(field=KwantWrdInMeter,
                                    naam='lengte',
                                    label='lengte',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Motorvangplank.lengte',
                                    definition='De lengte van de motorvangplank in meter.',
                                    owner=self)

        self._schokindexMvp = OTLAttribuut(field=KlLEACSchokindexMVP,
                                           naam='schokindexMvp',
                                           label='schokindex motorvangplank',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Motorvangplank.schokindexMvp',
                                           definition='Head injury criterium (HIC) van een motorvangplank.',
                                           owner=self)

        self._snelheidsklasse = OTLAttribuut(field=KlLEACSnelheidsklasse,
                                             naam='snelheidsklasse',
                                             label='snelheidsklasse',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Motorvangplank.snelheidsklasse',
                                             definition='De snelheid waarmee de testen uitgevoerd worden en of deze plaatsvinden op een continu of discontinu (niet in gebruik bij AWV) systeem.',
                                             owner=self)

        self._werkingsbreedteMvpwd = OTLAttribuut(field=KwantWrdInMeter,
                                                  naam='werkingsbreedteMvpwd',
                                                  label='werkingsbreedte mvpwd',
                                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Motorvangplank.werkingsbreedteMvpwd',
                                                  definition='De afstand tussen de voorkant van het onvervormd systeem tot de maximale dynamische laterale positie van elk onderdeel van het systeem.',
                                                  owner=self)

    @property
    def lengte(self) -> KwantWrdInMeterWaarden:
        """De lengte van de motorvangplank in meter."""
        return self._lengte.get_waarde()

    @lengte.setter
    def lengte(self, value):
        self._lengte.set_waarde(value, owner=self)

    @property
    def schokindexMvp(self) -> str:
        """Head injury criterium (HIC) van een motorvangplank."""
        return self._schokindexMvp.get_waarde()

    @schokindexMvp.setter
    def schokindexMvp(self, value):
        self._schokindexMvp.set_waarde(value, owner=self)

    @property
    def snelheidsklasse(self) -> str:
        """De snelheid waarmee de testen uitgevoerd worden en of deze plaatsvinden op een continu of discontinu (niet in gebruik bij AWV) systeem."""
        return self._snelheidsklasse.get_waarde()

    @snelheidsklasse.setter
    def snelheidsklasse(self, value):
        self._snelheidsklasse.set_waarde(value, owner=self)

    @property
    def werkingsbreedteMvpwd(self) -> KwantWrdInMeterWaarden:
        """De afstand tussen de voorkant van het onvervormd systeem tot de maximale dynamische laterale positie van elk onderdeel van het systeem."""
        return self._werkingsbreedteMvpwd.get_waarde()

    @werkingsbreedteMvpwd.setter
    def werkingsbreedteMvpwd(self, value):
        self._werkingsbreedteMvpwd.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.SerienummerObject import SerienummerObject
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from ...Datatypes.DtcDocument import DtcDocument, DtcDocumentWaarden
from ...Datatypes.DtcOlieType import DtcOlieType, DtcOlieTypeWaarden
from otlmow_model.OtlmowModel.BaseClasses.FloatOrDecimalField import FloatOrDecimalField
from ...Datatypes.KlTandwielkastMerk import KlTandwielkastMerk
from ...Datatypes.KlTandwielkastModelnaam import KlTandwielkastModelnaam
from ...Datatypes.KwantWrdInLiter import KwantWrdInLiter, KwantWrdInLiterWaarden
from otlmow_model.OtlmowModel.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Tandwielkast(SerienummerObject, AIMNaamObject, PuntGeometrie):
    """Systeem dat mechanisch vermogen van een motor omzet naar mechanisch vermogen met een kracht/snelheidsverhouding op maat van een bewegingsmechanisme."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Tandwielkast'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Dichting', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Flenskoppeling', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Naaf', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Onderstel', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Riemschijf', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Tandwiel', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Overbrenging', direction='o')  # o = direction: outgoing

        self._hoeveelheidOlie = OTLAttribuut(field=KwantWrdInLiter,
                                             naam='hoeveelheidOlie',
                                             label='hoeveelheid olie',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Tandwielkast.hoeveelheidOlie',
                                             definition='De hoeveelheid olie die vereist is voor het normaal functioneren van de reductiekast, zoals berekend bij installatie van de reductiekast.',
                                             owner=self)

        self._merk = OTLAttribuut(field=KlTandwielkastMerk,
                                  naam='merk',
                                  label='merk',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Tandwielkast.merk',
                                  definition='Het merk van de reductiekast.',
                                  owner=self)

        self._modelnaam = OTLAttribuut(field=KlTandwielkastModelnaam,
                                       naam='modelnaam',
                                       label='modelnaam',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Tandwielkast.modelnaam',
                                       definition='De modelnaam volgens de fabrikant van de reductiekast.',
                                       owner=self)

        self._reductieverhouding = OTLAttribuut(field=FloatOrDecimalField,
                                                naam='reductieverhouding',
                                                label='reductieverhouding',
                                                objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Tandwielkast.reductieverhouding',
                                                definition='Geeft de reductieverhouding van het uitgaande toerental tegenover het ingaande toerental weer.',
                                                owner=self)

        self._technischeFiche = OTLAttribuut(field=DtcDocument,
                                             naam='technischeFiche',
                                             label='technische fiche',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Tandwielkast.technischeFiche',
                                             definition='De technische fiche van de tandwielkast.',
                                             owner=self)

        self._typeOlie = OTLAttribuut(field=DtcOlieType,
                                      naam='typeOlie',
                                      label='type olie',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Tandwielkast.typeOlie',
                                      definition='Geeft aan welk type olie gebruikt wordt in deze reductiekast.',
                                      owner=self)

    @property
    def hoeveelheidOlie(self) -> KwantWrdInLiterWaarden:
        """De hoeveelheid olie die vereist is voor het normaal functioneren van de reductiekast, zoals berekend bij installatie van de reductiekast."""
        return self._hoeveelheidOlie.get_waarde()

    @hoeveelheidOlie.setter
    def hoeveelheidOlie(self, value):
        self._hoeveelheidOlie.set_waarde(value, owner=self)

    @property
    def merk(self) -> str:
        """Het merk van de reductiekast."""
        return self._merk.get_waarde()

    @merk.setter
    def merk(self, value):
        self._merk.set_waarde(value, owner=self)

    @property
    def modelnaam(self) -> str:
        """De modelnaam volgens de fabrikant van de reductiekast."""
        return self._modelnaam.get_waarde()

    @modelnaam.setter
    def modelnaam(self, value):
        self._modelnaam.set_waarde(value, owner=self)

    @property
    def reductieverhouding(self) -> float:
        """Geeft de reductieverhouding van het uitgaande toerental tegenover het ingaande toerental weer."""
        return self._reductieverhouding.get_waarde()

    @reductieverhouding.setter
    def reductieverhouding(self, value):
        self._reductieverhouding.set_waarde(value, owner=self)

    @property
    def technischeFiche(self) -> DtcDocumentWaarden:
        """De technische fiche van de tandwielkast."""
        return self._technischeFiche.get_waarde()

    @technischeFiche.setter
    def technischeFiche(self, value):
        self._technischeFiche.set_waarde(value, owner=self)

    @property
    def typeOlie(self) -> DtcOlieTypeWaarden:
        """Geeft aan welk type olie gebruikt wordt in deze reductiekast."""
        return self._typeOlie.get_waarde()

    @typeOlie.setter
    def typeOlie(self, value):
        self._typeOlie.set_waarde(value, owner=self)



# coding=utf-8
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from otlmow_model.OtlmowModel.GeometrieTypes.VlakGeometrie import VlakGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Spaarbekken(AIMNaamObject, VlakGeometrie):
    """Een plaats om water tijdelijk op te slaan voor later gebruik."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Spaarbekken'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Buis', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#LinkendElement', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Gracht', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Buis', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#LinkendElement', direction='o')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#SluitAanOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Gracht', direction='o')  # o = direction: outgoing



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from ...Datatypes.DtcDocument import DtcDocument, DtcDocumentWaarden
from ...Datatypes.KlMIVLusUitslijprichting import KlMIVLusUitslijprichting
from ...Datatypes.KlMIVLusZichtbaarheid import KlMIVLusZichtbaarheid
from otlmow_model.OtlmowModel.GeometrieTypes.LijnGeometrie import LijnGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class MIVLus(AIMNaamObject, LijnGeometrie):
    """Meten in Vlaanderen : inductieve lus,ingeslepen in het wegdek."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#MIVLus'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Laag', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HoortBij', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#MIVMeetpunt', direction='o', deprecated='2.9.0')  # o = direction: outgoing
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#MIVMeetpunt', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Doorverbinddoos', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Kabelmof', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#LoopTerminationAndProtection', direction='u')  # u = unidirectional

        self._meetrapport = OTLAttribuut(field=DtcDocument,
                                         naam='meetrapport',
                                         label='meetrapport',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#MIVLus.meetrapport',
                                         usagenote='Attribuut uit gebruik sinds versie 2.9.0 ',
                                         deprecated_version='2.9.0',
                                         definition='De elektrische eigenschappen van de lus: R, L, C en de isolatieweerstand. Dit verzekert naast de afmetingen mee de voorziene nauwkeurigheid van de voertuigmetingen.',
                                         owner=self)

        self._uitslijprichting = OTLAttribuut(field=KlMIVLusUitslijprichting,
                                              naam='uitslijprichting',
                                              label='uitslijprichting',
                                              objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#MIVLus.uitslijprichting',
                                              usagenote='Attribuut uit gebruik sinds versie 2.9.0 ',
                                              deprecated_version='2.9.0',
                                              definition='De uitlopers van de lus gaan naar links of naar rechts bekeken ten opzichte van de rijrichting.',
                                              owner=self)

        self._zichtbaarheid = OTLAttribuut(field=KlMIVLusZichtbaarheid,
                                           naam='zichtbaarheid',
                                           label='zichtbaarheid',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#MIVLus.zichtbaarheid',
                                           usagenote='Attribuut uit gebruik sinds versie 2.9.0 ',
                                           deprecated_version='2.9.0',
                                           definition='Is dus lus zichtbaar in het wegdek of bedekt door een toplaag.',
                                           owner=self)

    @property
    def meetrapport(self) -> DtcDocumentWaarden:
        """De elektrische eigenschappen van de lus: R, L, C en de isolatieweerstand. Dit verzekert naast de afmetingen mee de voorziene nauwkeurigheid van de voertuigmetingen."""
        return self._meetrapport.get_waarde()

    @meetrapport.setter
    def meetrapport(self, value):
        self._meetrapport.set_waarde(value, owner=self)

    @property
    def uitslijprichting(self) -> str:
        """De uitlopers van de lus gaan naar links of naar rechts bekeken ten opzichte van de rijrichting."""
        return self._uitslijprichting.get_waarde()

    @uitslijprichting.setter
    def uitslijprichting(self, value):
        self._uitslijprichting.set_waarde(value, owner=self)

    @property
    def zichtbaarheid(self) -> str:
        """Is dus lus zichtbaar in het wegdek of bedekt door een toplaag."""
        return self._zichtbaarheid.get_waarde()

    @zichtbaarheid.setter
    def zichtbaarheid(self, value):
        self._zichtbaarheid.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlBewegingsvrijheidInVlakBijOplegging(KeuzelijstField):
    """De bewegingsvrijheid in het vlak bij een oplegging."""
    naam = 'KlBewegingsvrijheidInVlakBijOplegging'
    label = 'Bewegingsvrijheid in vlak bij oplegging'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlBewegingsvrijheidInVlakBijOplegging'
    definition = 'De bewegingsvrijheid in het vlak bij een oplegging.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlBewegingsvrijheidInVlakBijOplegging'
    options = {
        'alzijdig-beweegbaar': KeuzelijstWaarde(invulwaarde='alzijdig-beweegbaar',
                                                label='alzijdig beweegbaar',
                                                status='ingebruik',
                                                definitie='alzijdig beweegbaar',
                                                objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBewegingsvrijheidInVlakBijOplegging/alzijdig-beweegbaar'),
        'dwars-beweegbaar': KeuzelijstWaarde(invulwaarde='dwars-beweegbaar',
                                             label='dwars beweegbaar',
                                             status='ingebruik',
                                             definitie='dwars beweegbaar',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBewegingsvrijheidInVlakBijOplegging/dwars-beweegbaar'),
        'langs-beweegbaar': KeuzelijstWaarde(invulwaarde='langs-beweegbaar',
                                             label='langs beweegbaar',
                                             status='ingebruik',
                                             definitie='langs beweegbaar',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBewegingsvrijheidInVlakBijOplegging/langs-beweegbaar'),
        'vast': KeuzelijstWaarde(invulwaarde='vast',
                                 label='vast',
                                 status='ingebruik',
                                 definitie='vast',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlBewegingsvrijheidInVlakBijOplegging/vast')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)




# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from abc import abstractmethod, ABC
from ...Datatypes.KlAIMToestand import KlAIMToestand


# Generated with OTLClassCreator. To modify: extend, do not edit
class AIMToestand(ABC):
    """Voegt een attribuut toe aan de subklasse dat de huidige stand in de levenscyclus van het object aangeeft."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/implementatieelement#AIMToestand'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    @abstractmethod
    def __init__(self):
        super().__init__()

        self._toestand = OTLAttribuut(field=KlAIMToestand,
                                      naam='toestand',
                                      label='AIM-toestand',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/implementatieelement#AIMToestand.toestand',
                                      definition='Geeft de actuele stand in de levenscyclus van het object.',
                                      owner=self)

    @property
    def toestand(self) -> str:
        """Geeft de actuele stand in de levenscyclus van het object."""
        return self._toestand.get_waarde()

    @toestand.setter
    def toestand(self, value):
        self._toestand.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.AndereLaag import AndereLaag
from ...Datatypes.DtcDocument import DtcDocument, DtcDocumentWaarden
from ...Datatypes.KlAlgBouwklassegroep import KlAlgBouwklassegroep
from ...Datatypes.KlDunneOverlagingType import KlDunneOverlagingType
from ...Datatypes.KlKleurSupp import KlKleurSupp
from ...Datatypes.KwantWrdInTon import KwantWrdInTon, KwantWrdInTonWaarden
from otlmow_model.OtlmowModel.GeometrieTypes.VlakGeometrie import VlakGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class DunneOverlaging(AndereLaag, VlakGeometrie):
    """Een dunne overlaging kan bestaan uit een SME overlaging, een antisliplaag, waterdichte toplaag, ...."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#DunneOverlaging'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Fundering', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Markering', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#SelNietSelLus', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Straatmeubilair', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IsInspectieVan', target='https://wegenenverkeer.data.vlaanderen.be/ns/proefenmeting#ProefEffectiefBindmiddelgehalte', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IsInspectieVan', target='https://wegenenverkeer.data.vlaanderen.be/ns/proefenmeting#ProefKorrelverdeling', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IsInspectieVan', target='https://wegenenverkeer.data.vlaanderen.be/ns/proefenmeting#ProefStroefheid', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IsInspectieVan', target='https://wegenenverkeer.data.vlaanderen.be/ns/proefenmeting#ProefTemperatuur', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#IsInspectieVan', target='https://wegenenverkeer.data.vlaanderen.be/ns/proefenmeting#ProefVisueleBeoordeling', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#LigtOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#BegroeidVoorkomen', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#LigtOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Hoppinzuil', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#LigtOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Laag', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#LigtOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#LijnvormigElement', direction='i')  # i = direction: incoming
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#LigtOp', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#VegetatieElement', direction='i')  # i = direction: incoming

        self._bouwklasse = OTLAttribuut(field=KlAlgBouwklassegroep,
                                        naam='bouwklasse',
                                        label='bouwklasse',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#DunneOverlaging.bouwklasse',
                                        definition='Een maat voor de verkeersbelasting over de volledige levensduur van de laag. De laag is ontworpen volgens de aangeduide bouwklasse.',
                                        owner=self)

        self._gewicht = OTLAttribuut(field=KwantWrdInTon,
                                     naam='gewicht',
                                     label='gewicht',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#DunneOverlaging.gewicht',
                                     definition='Het gewicht van de dunne overlaging in ton.',
                                     owner=self)

        self._kleur = OTLAttribuut(field=KlKleurSupp,
                                   naam='kleur',
                                   label='kleur',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#DunneOverlaging.kleur',
                                   definition='De kleur van de dunne overlaging.',
                                   owner=self)

        self._technischeFiche = OTLAttribuut(field=DtcDocument,
                                             naam='technischeFiche',
                                             label='technische fiche',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#DunneOverlaging.technischeFiche',
                                             definition='De technische fiche van de dunne overlaging',
                                             owner=self)

        self._type = OTLAttribuut(field=KlDunneOverlagingType,
                                  naam='type',
                                  label='type',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#DunneOverlaging.type',
                                  definition='Het type SME overlaging of antisliplaag.',
                                  owner=self)

    @property
    def bouwklasse(self) -> str:
        """Een maat voor de verkeersbelasting over de volledige levensduur van de laag. De laag is ontworpen volgens de aangeduide bouwklasse."""
        return self._bouwklasse.get_waarde()

    @bouwklasse.setter
    def bouwklasse(self, value):
        self._bouwklasse.set_waarde(value, owner=self)

    @property
    def gewicht(self) -> KwantWrdInTonWaarden:
        """Het gewicht van de dunne overlaging in ton."""
        return self._gewicht.get_waarde()

    @gewicht.setter
    def gewicht(self, value):
        self._gewicht.set_waarde(value, owner=self)

    @property
    def kleur(self) -> str:
        """De kleur van de dunne overlaging."""
        return self._kleur.get_waarde()

    @kleur.setter
    def kleur(self, value):
        self._kleur.set_waarde(value, owner=self)

    @property
    def technischeFiche(self) -> DtcDocumentWaarden:
        """De technische fiche van de dunne overlaging"""
        return self._technischeFiche.get_waarde()

    @technischeFiche.setter
    def technischeFiche(self, value):
        self._technischeFiche.set_waarde(value, owner=self)

    @property
    def type(self) -> str:
        """Het type SME overlaging of antisliplaag."""
        return self._type.get_waarde()

    @type.setter
    def type(self, value):
        self._type.set_waarde(value, owner=self)



# coding=utf-8
from abc import abstractmethod
from ...Classes.Abstracten.StaalsoortObject import StaalsoortObject
from ...Classes.Abstracten.TechnischDocument import TechnischDocument
from otlmow_model.OtlmowModel.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Ophanging(StaalsoortObject, TechnischDocument, PuntGeometrie):
    """Abstracte om attributen en relaties te bundelen voor ophanging. Een ophanging maakt de koppeling tussen de actuator en de vaste constructie."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Ophanging'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    @abstractmethod
    def __init__(self):
        super().__init__()



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.AanhorigheidSluisStuw import AanhorigheidSluisStuw
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from ...Datatypes.KlTypeFendering import KlTypeFendering
from ...Datatypes.KwantWrdInMegajoule import KwantWrdInMegajoule, KwantWrdInMegajouleWaarden
from otlmow_model.OtlmowModel.GeometrieTypes.PuntGeometrie import PuntGeometrie
from otlmow_model.OtlmowModel.GeometrieTypes.LijnGeometrie import LijnGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Fendering(AanhorigheidSluisStuw, AIMNaamObject, PuntGeometrie, LijnGeometrie):
    """Een fender dient om de kinetische energie van een afmerend schip op te vangen en op die manier schade aan een schip of de achterliggende constructie te vermijden."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Fendering'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Dukdalf', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/installatie#Kesp', direction='u')  # u = unidirectional

        self._energie = OTLAttribuut(field=KwantWrdInMegajoule,
                                     naam='energie',
                                     label='energie',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Fendering.energie',
                                     definition='De karakteristieke energie die de fender kan opnemen uitgedrukt in megajoule.',
                                     owner=self)

        self._typeFendering = OTLAttribuut(field=KlTypeFendering,
                                           naam='typeFendering',
                                           label='type fendering',
                                           objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Fendering.typeFendering',
                                           definition='Het type fendering.',
                                           owner=self)

    @property
    def energie(self) -> KwantWrdInMegajouleWaarden:
        """De karakteristieke energie die de fender kan opnemen uitgedrukt in megajoule."""
        return self._energie.get_waarde()

    @energie.setter
    def energie(self, value):
        self._energie.set_waarde(value, owner=self)

    @property
    def typeFendering(self) -> str:
        """Het type fendering."""
        return self._typeFendering.get_waarde()

    @typeFendering.setter
    def typeFendering(self, value):
        self._typeFendering.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.Abstracten.ElektrischComponentennummerObject import ElektrischComponentennummerObject
from ...Classes.Abstracten.SerienummerObject import SerienummerObject
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject
from otlmow_model.OtlmowModel.BaseClasses.BooleanField import BooleanField
from ...Datatypes.KlAansluitingskabel import KlAansluitingskabel
from ...Datatypes.KlAlgFaalmodusType import KlAlgFaalmodusType
from ...Datatypes.KlSlotGebruik import KlSlotGebruik
from ...Datatypes.KlSlotMerk import KlSlotMerk
from ...Datatypes.KlSlotModelnaam import KlSlotModelnaam
from ...Datatypes.KlSlotType import KlSlotType
from ...Datatypes.KwantWrdInMillimeter import KwantWrdInMillimeter, KwantWrdInMillimeterWaarden
from otlmow_model.OtlmowModel.BaseClasses.StringField import StringField
from otlmow_model.OtlmowModel.GeometrieTypes.PuntGeometrie import PuntGeometrie


# Generated with OTLClassCreator. To modify: extend, do not edit
class Slot(ElektrischComponentennummerObject, SerienummerObject, AIMNaamObject, PuntGeometrie):
    """Onderdeel van het slotmechanisme dat instaat voor het gesloten houden van deuren, poorten, luiken. Dit is zonder de cilinder."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Slot'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#Toegangselement', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Bevestiging', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Slotcilinder', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Lockermanagementmodule', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#TGCUitbreidingsModule', direction='u')  # u = unidirectional
        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Sturing', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Toegangscontroller', direction='u')  # u = unidirectional

        self._aansluitingskabel = OTLAttribuut(field=KlAansluitingskabel,
                                               naam='aansluitingskabel',
                                               label='aansluitingskabel',
                                               objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Slot.aansluitingskabel',
                                               definition='Geeft aan of er een kabel / welk type kabel er gebruikt wordt om communicatie van en naar dit element mogelijk te maken.',
                                               owner=self)

        self._asafstand = OTLAttribuut(field=KwantWrdInMillimeter,
                                       naam='asafstand',
                                       label='asafstand',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Slot.asafstand',
                                       definition='De afstand tussen het midden van de as van het sleutel- of cilindergat en het midden van de as van het krukgat. Wordt ook wel entre-axe genoemd.',
                                       owner=self)

        self._doornmaat = OTLAttribuut(field=KwantWrdInMillimeter,
                                       naam='doornmaat',
                                       label='doornmaat',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Slot.doornmaat',
                                       definition='De afstand tussen de voorplaat en het midden van de as van het krukgat. Wordt ook wel entree genoemd.',
                                       owner=self)

        self._faalmodus = OTLAttribuut(field=KlAlgFaalmodusType,
                                       naam='faalmodus',
                                       label='faalmodus',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Slot.faalmodus',
                                       definition='Geeft de faalmodus van het slot aan. Is het slot fail-safe, dan kan je bij een stroompanne steeds binnen en buiten. Is het slot fail-secure, dan gaat die bij een stroompanne op slot.',
                                       owner=self)

        self._heeftMeerpuntsvergrendeling = OTLAttribuut(field=BooleanField,
                                                         naam='heeftMeerpuntsvergrendeling',
                                                         label='heeft meerpuntsvergrendeling',
                                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Slot.heeftMeerpuntsvergrendeling',
                                                         definition='Geeft aan of het slot meerpuntsvergrendeld is.',
                                                         owner=self)

        self._merk = OTLAttribuut(field=KlSlotMerk,
                                  naam='merk',
                                  label='merk',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Slot.merk',
                                  definition='Het merk van het slot.',
                                  owner=self)

        self._modelnaam = OTLAttribuut(field=KlSlotModelnaam,
                                       naam='modelnaam',
                                       label='modelnaam',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Slot.modelnaam',
                                       definition='De modelnaam van het slot.',
                                       owner=self)

        self._slotGebruik = OTLAttribuut(field=KlSlotGebruik,
                                         naam='slotGebruik',
                                         label='slot gebruik',
                                         objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Slot.slotGebruik',
                                         definition='Geeft aan langs welke kan het slot bruikbaar is. Hierbij kijk je naar de deur vanuit de kant dat je hem open kan duwen. Een slot kan gemaakt zijn om ofwel links, ofwel rechts geïnstalleerd te worden, of kan voor beide kanten bruikbaar zijn.',
                                         owner=self)

        self._type = OTLAttribuut(field=KlSlotType,
                                  naam='type',
                                  label='type',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Slot.type',
                                  definition='Het type slot.',
                                  owner=self)

        self._uitvoering = OTLAttribuut(field=StringField,
                                        naam='uitvoering',
                                        label='uitvoering',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Slot.uitvoering',
                                        definition='Vrij invulveld voor verdere specificatie van hoe het slot is uitgevoerd.',
                                        owner=self)

    @property
    def aansluitingskabel(self) -> str:
        """Geeft aan of er een kabel / welk type kabel er gebruikt wordt om communicatie van en naar dit element mogelijk te maken."""
        return self._aansluitingskabel.get_waarde()

    @aansluitingskabel.setter
    def aansluitingskabel(self, value):
        self._aansluitingskabel.set_waarde(value, owner=self)

    @property
    def asafstand(self) -> KwantWrdInMillimeterWaarden:
        """De afstand tussen het midden van de as van het sleutel- of cilindergat en het midden van de as van het krukgat. Wordt ook wel entre-axe genoemd."""
        return self._asafstand.get_waarde()

    @asafstand.setter
    def asafstand(self, value):
        self._asafstand.set_waarde(value, owner=self)

    @property
    def doornmaat(self) -> KwantWrdInMillimeterWaarden:
        """De afstand tussen de voorplaat en het midden van de as van het krukgat. Wordt ook wel entree genoemd."""
        return self._doornmaat.get_waarde()

    @doornmaat.setter
    def doornmaat(self, value):
        self._doornmaat.set_waarde(value, owner=self)

    @property
    def faalmodus(self) -> str:
        """Geeft de faalmodus van het slot aan. Is het slot fail-safe, dan kan je bij een stroompanne steeds binnen en buiten. Is het slot fail-secure, dan gaat die bij een stroompanne op slot."""
        return self._faalmodus.get_waarde()

    @faalmodus.setter
    def faalmodus(self, value):
        self._faalmodus.set_waarde(value, owner=self)

    @property
    def heeftMeerpuntsvergrendeling(self) -> bool:
        """Geeft aan of het slot meerpuntsvergrendeld is."""
        return self._heeftMeerpuntsvergrendeling.get_waarde()

    @heeftMeerpuntsvergrendeling.setter
    def heeftMeerpuntsvergrendeling(self, value):
        self._heeftMeerpuntsvergrendeling.set_waarde(value, owner=self)

    @property
    def merk(self) -> str:
        """Het merk van het slot."""
        return self._merk.get_waarde()

    @merk.setter
    def merk(self, value):
        self._merk.set_waarde(value, owner=self)

    @property
    def modelnaam(self) -> str:
        """De modelnaam van het slot."""
        return self._modelnaam.get_waarde()

    @modelnaam.setter
    def modelnaam(self, value):
        self._modelnaam.set_waarde(value, owner=self)

    @property
    def slotGebruik(self) -> str:
        """Geeft aan langs welke kan het slot bruikbaar is. Hierbij kijk je naar de deur vanuit de kant dat je hem open kan duwen. Een slot kan gemaakt zijn om ofwel links, ofwel rechts geïnstalleerd te worden, of kan voor beide kanten bruikbaar zijn."""
        return self._slotGebruik.get_waarde()

    @slotGebruik.setter
    def slotGebruik(self, value):
        self._slotGebruik.set_waarde(value, owner=self)

    @property
    def type(self) -> str:
        """Het type slot."""
        return self._type.get_waarde()

    @type.setter
    def type(self, value):
        self._type.set_waarde(value, owner=self)

    @property
    def uitvoering(self) -> str:
        """Vrij invulveld voor verdere specificatie van hoe het slot is uitgevoerd."""
        return self._uitvoering.get_waarde()

    @uitvoering.setter
    def uitvoering(self, value):
        self._uitvoering.set_waarde(value, owner=self)



# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from ...Classes.ImplementatieElement.AIMObject import AIMObject
from ...Datatypes.KlGrondbestemming import KlGrondbestemming
from ...Datatypes.KlUitgravingSoorten import KlUitgravingSoorten
from ...Datatypes.KwantWrdInKubiekeMeter import KwantWrdInKubiekeMeter, KwantWrdInKubiekeMeterWaarden
from ...Datatypes.KwantWrdInTon import KwantWrdInTon, KwantWrdInTonWaarden


# Generated with OTLClassCreator. To modify: extend, do not edit
class Uitgraving(AIMObject):
    """Wordt beschouwd als de verzameling van beheeractiviteiten die uitgevoerd kunnen worden op grond."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/levenscyclus#Uitgraving'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()

        self.add_valid_relation(relation='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#HeeftBeheer', target='https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Grond', direction='i')  # i = direction: incoming

        self._bestemming = OTLAttribuut(field=KlGrondbestemming,
                                        naam='bestemming',
                                        label='bestemming',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/levenscyclus#Uitgraving.bestemming',
                                        definition='De bestemmingen of doelen van de grond.',
                                        owner=self)

        self._gewicht = OTLAttribuut(field=KwantWrdInTon,
                                     naam='gewicht',
                                     label='gewicht',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/levenscyclus#Uitgraving.gewicht',
                                     definition='Het gewicht van de grondlaag in ton.',
                                     owner=self)

        self._soortUitgraving = OTLAttribuut(field=KlUitgravingSoorten,
                                             naam='soortUitgraving',
                                             label='soort uitgraving',
                                             objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/levenscyclus#Uitgraving.soortUitgraving',
                                             definition='De specificatie van type grond bij uitgraving.',
                                             owner=self)

        self._volume = OTLAttribuut(field=KwantWrdInKubiekeMeter,
                                    naam='volume',
                                    label='volume',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/levenscyclus#Uitgraving.volume',
                                    definition='Het volume van de grondlaag in kubieke meter.',
                                    owner=self)

    @property
    def bestemming(self) -> str:
        """De bestemmingen of doelen van de grond."""
        return self._bestemming.get_waarde()

    @bestemming.setter
    def bestemming(self, value):
        self._bestemming.set_waarde(value, owner=self)

    @property
    def gewicht(self) -> KwantWrdInTonWaarden:
        """Het gewicht van de grondlaag in ton."""
        return self._gewicht.get_waarde()

    @gewicht.setter
    def gewicht(self, value):
        self._gewicht.set_waarde(value, owner=self)

    @property
    def soortUitgraving(self) -> str:
        """De specificatie van type grond bij uitgraving."""
        return self._soortUitgraving.get_waarde()

    @soortUitgraving.setter
    def soortUitgraving(self, value):
        self._soortUitgraving.set_waarde(value, owner=self)

    @property
    def volume(self) -> KwantWrdInKubiekeMeterWaarden:
        """Het volume van de grondlaag in kubieke meter."""
        return self._volume.get_waarde()

    @volume.setter
    def volume(self, value):
        self._volume.set_waarde(value, owner=self)



# coding=utf-8
import re

from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut
from abc import abstractmethod
from ...Classes.ImplementatieElement.AIMNaamObject import AIMNaamObject, NaamField


class NaampadField(NaamField):
    def __init__(self, naam: str, label: str, objectUri: str, definition: str, owner):
        super().__init__(naam, label, objectUri, definition, owner)

    @classmethod
    def validate(cls, value, attribuut) -> bool:
        if re.match(r'^[\w.\-]+[/[\w.\-]+]*$', value) is None:
            return False
        if attribuut.owner.naam is not None:
            return value.split('/')[-1] == attribuut.owner.naam
        return True

    @classmethod
    def create_dummy_data(cls) -> str:
        return 'dummy/dummy'

# Generated with OTLClassCreator. To modify: extend, do not edit
class NaampadObject(AIMNaamObject):
    """Abstracte als de basisklasse voor elk OTL object dat gebruik maakt van een naampad."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/implementatieelement#NaampadObject'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    @abstractmethod
    def __init__(self):
        super().__init__()

        self._naampad = OTLAttribuut(field=NaampadField,
                                     naam='naampad',
                                     label='naampad',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/ns/implementatieelement#NaampadObject.naampad',
                                     usagenote='Dient consistent te zijn met de naam.',
                                     definition='Een set van objecten (bv. collecties) die aanduiden waar het object zich bevindt in de objectenboom (EM-Infra).',
                                     owner=self)

    @property
    def naampad(self) -> str:
        """Een set van objecten (bv. collecties) die aanduiden waar het object zich bevindt in de objectenboom (EM-Infra)."""
        return self._naampad.get_waarde()

    @naampad.setter
    def naampad(self, value):
        self._naampad.set_waarde(value, owner=self)
